@@ -1,31 +1,31 @@
       PROGRAM XCOM
-C
-C       Version 3.1, 23 June 1999.  
-C       
-C       Copyright 1999, Martin J. Berger. Permission is given to
-C       use the program for non-commercial purposes. 
-C
-C       A descripton of the program is available in National Bureau of
-C       Standards Report NBSIR-87 by M. J. Berger and J. H. Hubbell. 
-C       The authors can be reached at the National Institute of
-C       Standards and Technology, Gaithersburg, MD 20899, Phone: (301)
-C       975-5550.
-C
-C       XCOM3 calculates tables of cross sections for the interactions
-C       of photons with any element, compound or mixture, for photons
-C       with energies between 1 keV and 100 GeV.
-C      
-C       Files MDATX3.001, MDATX3.002,..., MDATX3.100 contain input data
-C       for each or the elements. 
-C
-C       XCOM3 uses the following subroutines:
-C       SPEC, FORM, MERGE, REV, SCOF, BSPOL and BLIN.
-C
+!
+!       Version 3.1, 23 June 1999.  
+!       
+!       Copyright 1999, Martin J. Berger. Permission is given to
+!       use the program for non-commercial purposes. 
+!
+!       A descripton of the program is available in National Bureau of
+!       Standards Report NBSIR-87 by M. J. Berger and J. H. Hubbell. 
+!       The authors can be reached at the National Institute of
+!       Standards and Technology, Gaithersburg, MD 20899, Phone: (301)
+!       975-5550.
+!
+!       XCOM3 calculates tables of cross sections for the interactions
+!       of photons with any element, compound or mixture, for photons
+!       with energies between 1 keV and 100 GeV.
+!      
+!       Files MDATX3.001, MDATX3.002,..., MDATX3.100 contain input data
+!       for each or the elements. 
+!
+!       XCOM3 uses the following subroutines:
+!       SPEC, FORM, MERGE, REV, SCOF, BSPOL and BLIN.
+!
        CHARACTER PSOR*30,INPUT*10, XFIL2*30,SUB*72,
      1 IND(100)*3,FF*1
-c///////
+!///////
        character*72 XFIL1
-c//////////
+!//////////
       PARAMETER (ME=1500,MEA=600,MEB=1800)                              SMS
       DIMENSION E(108),AFIT(108),BFIT(108),CFIT(108),DFIT(108),
      1 SCATCO(108),SCATIN(108),PHOT(108),PAIRAT(108),PAIREL(108),
@@ -36,9 +36,9 @@ c//////////
      6 PRAT(ME),PREL(ME),AT(ME),ATNC(ME),EN(ME),ENL(ME),EAD(MEA),
      7 IDG(14),EDGEN(14),ADG(14),EDGE(94),ALAB(ME),X(MEB,8),            SMS
      8 ENG(35,14),ENGL(35),PHCL(35),KMX(14)
-c////////
+!////////
       integer klena
-c////////
+!////////
       DATA  NENG/80/,AVOG/0.60221367/
       DATA EPAIR1/1.022007E+06/,EPAIR2/2.044014E+06/
       INCLUDE 'ENB.DAT'
@@ -47,18 +47,18 @@ c////////
     5 FORMAT(A)
    10 FORMAT(1H )
       FF=CHAR(12)
-ckk      PRINT *,' Program XCOM, Version 3.1'                             
+!kk      PRINT *,' Program XCOM, Version 3.1'                             
       write(0,*)' Program XCOM, Version 3.1'                              
       write(0,*)' M.J.Berger and J.H.Hubbell, 23 June 1999'               
-ckk      PRINT 10
+!kk      PRINT 10
       SUB=" "
       CALL SPEC(SUB,NF,KMAX,NZ,WEIGHT,JENG,EAD,NEGO,PSOR)
       DO 11 J=1,30
-      IF(PSOR(J:J).NE.' ') GO TO 12
+      IF(PSOR(J:J) .NE. ' ') GO TO 12
    11 CONTINUE
    12 JBEG=J
       DO 13 J=30,1,-1
-      IF(PSOR(J:J).NE.' ') GO TO 14
+      IF(PSOR(J:J) .NE. ' ') GO TO 14
    13 CONTINUE
    14 JFIN=J
       GO TO (60,30,15),NEGO
@@ -253,9 +253,9 @@ ckk      PRINT 10
       GO TO 438
   437 FRAC=AVOG*WEIGHT(K)/ATWT
   438 ECUT=0.0
-      IF (MAXEDG.GT.0) ECUT=EDGEN(MAXEDG)
+      IF (MAXEDG .GT. 0) ECUT=EDGEN(MAXEDG)
       IF(NENG-80)460,440,460
-  440 IF (NEGO.EQ.3) GO TO 460                                          SMS
+  440 IF (NEGO .EQ. 3) GO TO 460                                          SMS
       DO 450 N=1,NENG
       SCTCO(N)=SCTCO(N)+FRAC*SATCO(N)
       SCTIN(N)=SCTIN(N)+FRAC*SATIN(N)
@@ -323,14 +323,14 @@ ckk      PRINT 10
   621 AT(N)=AVOG*AT(N)/ATWT
       ATNC(N)=AVOG*ATNC(N)/ATWT
   622 CONTINUE
-ckk      PRINT *,' Specify file on which output (cross section table)'
-ckk      PRINT *,' is to be stored. (Specification can include drive'
-ckk      PRINT *,' and path): '
-ckkkk      READ 5, XFIL1
-c///////////
-c      XFIL1=dir(1:ndir)//SUB(1:klena(SUB))//".xcom"
-c///////
-c      OPEN (UNIT=8,FILE=XFIL1)
+!kk      PRINT *,' Specify file on which output (cross section table)'
+!kk      PRINT *,' is to be stored. (Specification can include drive'
+!kk      PRINT *,' and path): '
+!kkkk      READ 5, XFIL1
+!///////////
+!      XFIL1=dir(1:ndir)//SUB(1:klena(SUB))//".xcom"
+!///////
+!      OPEN (UNIT=8,FILE=XFIL1)
       NN=1
       JTAL=0
       DO 880 N=1,NENG
@@ -361,50 +361,50 @@ c      OPEN (UNIT=8,FILE=XFIL1)
   710 WRITE (*,10)
       GO TO (711,715,715), NF
   711 WRITE (*,712)
-C 712 FORMAT(8X,'PHOTON',6X,'SCATTERING',
-C    16X,'PHOTO-',4X,'PAIR PRODUCTION',
-C    22X,'TOT.CROSS SECTION')
+! 712 FORMAT(8X,'PHOTON',6X,'SCATTERING',
+!    16X,'PHOTO-',4X,'PAIR PRODUCTION',
+!    22X,'TOT.CROSS SECTION')
   712 FORMAT(9X,'PHOTON',7X,'SCATTERING',                               SMS
      17X,'PHOTO-',5X,'PAIR PRODUCTION',                                 SMS
      24X,'TOT.CROSS SECTION')                                           SMS
       GO TO 724
   715 WRITE (*,720)
-C 720 FORMAT(8X,'PHOTON',6X,'SCATTERING',
-C    16X,'PHOTO-',4X,'PAIR PRODUCTION',
-C    22X,'TOTAL ATTENUATION')
+! 720 FORMAT(8X,'PHOTON',6X,'SCATTERING',
+!    16X,'PHOTO-',4X,'PAIR PRODUCTION',
+!    22X,'TOTAL ATTENUATION')
   720 FORMAT(9X,'PHOTON',7X,'SCATTERING',                               SMS
      17X,'PHOTO-',5X,'PAIR PRODUCTION',                                 SMS
      24X,'TOTAL ATTENUATION')                                           SMS
   724 WRITE (*,730)
-C 730 FORMAT(8X,'ENERGY',3X,'COHERENT INCOHER. ELECTRIC',
-C    14X,'IN',7X,'IN',7X,'WITH',3X,'WITHOUT')
+! 730 FORMAT(8X,'ENERGY',3X,'COHERENT INCOHER. ELECTRIC',
+!    14X,'IN',7X,'IN',7X,'WITH',3X,'WITHOUT')
   730 FORMAT(9X,'ENERGY',3X,'COHERENT  INCOHER.  ELECTRIC',             SMS
      15X,'IN',8X,'IN',8X,'WITH',4X,'WITHOUT')                           SMS
       WRITE (*,740)
-C 740 FORMAT(34X,'ABSORPTION NUCLEAR ELECTRON  COHERENT COHERENT')
+! 740 FORMAT(34X,'ABSORPTION NUCLEAR ELECTRON  COHERENT COHERENT')
   740 FORMAT(37X,'ABSORPTION  NUCLEAR  ELECTRON   COHERENT  COHERENT')  SMS
       WRITE (*,750)
-C 750 FORMAT(46X,'FIELD',4X,'FIELD',4X,'SCATT.',3X,'SCATT.')
+! 750 FORMAT(46X,'FIELD',4X,'FIELD',4X,'SCATT.',3X,'SCATT.')
   750 FORMAT(50X,'FIELD',5X,'FIELD',5X,'SCATT.',4X,'SCATT.')            SMS
       GO TO (791,780,760), NF
   760 WRITE (*,770)
-C 770 FORMAT(9X,'(MeV)',2X,7(2X,'(cm2/g)'))
+! 770 FORMAT(9X,'(MeV)',2X,7(2X,'(cm2/g)'))
   770 FORMAT(10X,'(MeV)',1X,7(3X,'(cm2/g)'))                            SMS
       GO TO 800
   780 WRITE (*,790)
-C 790 FORMAT(9X,'(MeV)',3X,5('(b/atom) '),2X,'(cm2/g)',2X,'(cm2/g)')
+! 790 FORMAT(9X,'(MeV)',3X,5('(b/atom) '),2X,'(cm2/g)',2X,'(cm2/g)')
   790 FORMAT(10X,'(MeV)',2X,5(1X,'(b/atom) '),2(3X,'(cm2/g)'))          SMS
       GO TO 800
   791 WRITE (*,792)
-C 792 FORMAT(9X,'(MeV)',3x,7('(b/atom) '))
+! 792 FORMAT(9X,'(MeV)',3x,7('(b/atom) '))
   792 FORMAT(10X,'(MeV)',2X,5(1X,'(b/atom) '),1X,2(1X,'(b/atom) '))     SMS
   800 WRITE (*,10)
-ckkk  805 ENN=EN(N)*(1.0E-06)
+!kkk  805 ENN=EN(N)*(1.0E-06)
   805 ENN=EN(N)*1.0E-09
       IF(KZ(N))870,870,810
   810 PHT1=PHT(N)-PHDIF(N)
       GO TO (812,811,812), NF
-C 811 AT1=AT(N)-0.6022045*PHDIF(N)/ATWT
+! 811 AT1=AT(N)-0.6022045*PHDIF(N)/ATWT
   811 AT1=AT(N)-AVOG*PHDIF(N)/ATWT                                      SMS
       ATNC1=ATNC(N)-AVOG*PHDIF(N)/ATWT
       GO TO 815
@@ -412,7 +412,7 @@ C 811 AT1=AT(N)-0.6022045*PHDIF(N)/ATWT
       ATNC1=ATNC(N)-PHDIF(N)
   815 WRITE(*,820) ENN,SCTCO(N),SCTIN(N),PHT1,
      1 PRAT(N),PREL(N),AT1,ATNC1
-C 820 FORMAT(7X,1PE10.3,1P7E9.2)
+! 820 FORMAT(7X,1PE10.3,1P7E9.2)
   820 FORMAT(7X,1PE10.3,1P7E10.3)                                       SMS
       WRITE (*,10)
       X(NN,1)=ENN
@@ -426,7 +426,7 @@ C 820 FORMAT(7X,1PE10.3,1P7E9.2)
       NN=NN+1
       WRITE(*,840) KZ(N),ALAB(N),ENN,SCTCO(N),SCTIN(N),PHT(N),
      1 PRAT(N),PREL(N),AT(N),ATNC(N)
-C 840 FORMAT(1X,I2,1X,A2,1X,1PE10.3,1P7E9.2)
+! 840 FORMAT(1X,I2,1X,A2,1X,1PE10.3,1P7E9.2)
   840 FORMAT(I3,1X,A2,1X,1PE10.3,1P7E10.3)                              SMS
       X(NN,1)=ENN
       X(NN,2)=SCTCO(N)
@@ -456,18 +456,18 @@ C 840 FORMAT(1X,I2,1X,A2,1X,1PE10.3,1P7E9.2)
       GO TO 850
   880 CONTINUE
       CLOSE (8)
-ckk      PRINT 890, XFIL1
-ckk  890 FORMAT(' Cross-section table with headings has been stored',
-ckk     1' in file ',A)
-ckk      PRINT *,' Options for further output:'
-ckk      PRINT *,'     1. No more output'
-ckk      PRINT *,'     2. Selected arrays stored on disk'
-ckk      PRINT *,' Enter choice: '
-ckk      READ *, NOUT
-c//////
+!kk      PRINT 890, XFIL1
+!kk  890 FORMAT(' Cross-section table with headings has been stored',
+!kk     1' in file ',A)
+!kk      PRINT *,' Options for further output:'
+!kk      PRINT *,'     1. No more output'
+!kk      PRINT *,'     2. Selected arrays stored on disk'
+!kk      PRINT *,' Enter choice: '
+!kk      READ *, NOUT
+!//////
       NOUT=1
       stop
-c///////
+!///////
       GO TO (1020,920), NOUT
   920 PRINT *,'  '
       PRINT *,' Specify file on which selected arrays are to be stored.'
@@ -544,16 +544,16 @@ c///////
       END 
 
       SUBROUTINE SPEC(SUBST,NFORM,MMAX,JZ,WT,JING,EADD,NELL,SOURCE)
-C     2 Apr 87. Reads various input parameters. 
+!     2 Apr 87. Reads various input parameters. 
       CHARACTER*72 FORMLA,FRM(100),SUBST
       CHARACTER*30 ENGIN,SOURCE
-c////////
+!////////
 #include "Zmedia.h"
       integer nmatter, icon, kgetenv2,  nbasepath
       character*70  basepath
-      record /epmedia/ media
+       type(epmedia)::  media
       character*2 symb
-c//////
+!//////
       CHARACTER  RESP*1                                                 SMS
       PARAMETER (MEA=1200)                                              SMS
       DIMENSION JZ(100),WT(100),JZ1(100),WT1(100),LH(100),WATE(100),
@@ -563,9 +563,9 @@ c//////
    12 FORMAT(A)
 
 
-ckkkk     PRINT *,' Enter name of substance: '
-ckkkk      READ 12, SUBST
-c///////
+!kkkk     PRINT *,' Enter name of substance: '
+!kkkk      READ 12, SUBST
+!///////
       SUBST=" "
       nmatter = kgetenv2("MATTER", SUBST)
       if(nmatter .le. 0) then
@@ -578,20 +578,20 @@ c///////
          stop 3456
       endif
       
-c      SUBST=SUBST(1:nmatter)//" "
-c      write(0,*) " nmatter=", nmatter
-c//////////
-ckk      PRINT 10
-ckkk      PRINT *,' Options for characterization of substance:'
-ckkk      PRINT *,'    1. Elemental substance, specified by atomic number'
-ckkk      PRINT *,'    2. Elemental substance, specified by chemical symbol'
-ckkk      PRINT *,'    3. Compound, specified by chemical formula'
-ckkk      PRINT *,'    4. Mixture of elements and/or compounds'
-ckkk      PRINT *,' Enter choice: '
-ckkk      READ *,NSUB
-c///////
+!      SUBST=SUBST(1:nmatter)//" "
+!      write(0,*) " nmatter=", nmatter
+!//////////
+!kk      PRINT 10
+!kkk      PRINT *,' Options for characterization of substance:'
+!kkk      PRINT *,'    1. Elemental substance, specified by atomic number'
+!kkk      PRINT *,'    2. Elemental substance, specified by chemical symbol'
+!kkk      PRINT *,'    3. Compound, specified by chemical formula'
+!kkk      PRINT *,'    4. Mixture of elements and/or compounds'
+!kkk      PRINT *,' Enter choice: '
+!kkk      READ *,NSUB
+!///////
       NSUB = 4
-ckkk      PRINT 10
+!kkk      PRINT 10
       GO TO(15,20,50,55),NSUB
    15 PRINT *,' Enter atomic number of element: '
       READ *, JZ(1)
@@ -623,15 +623,15 @@ ckkk      PRINT 10
       JZ(N)=JZTEMP
       WT(N)=WTTEMP
    40 CONTINUE
-C     GO TO 150                                                         SMS
-C        NOW THAT IN ASCENDING ORDER, COMBINE IDENTICAL Zs              SMS
+!     GO TO 150                                                         SMS
+!        NOW THAT IN ASCENDING ORDER, COMBINE IDENTICAL Zs              SMS
       M=0                                                               SMS
    42 M=M+1                                                             SMS
-      IF (M.GE.MMAX) GO TO 150                                          SMS
-   44 IF (JZ(M).NE.JZ(M+1)) GO TO 42                                    SMS
+      IF (M .GE. MMAX) GO TO 150                                          SMS
+   44 IF (JZ(M) .NE. JZ(M+1)) GO TO 42                                    SMS
       WT(M)=WT(M)+WT(M+1)                                               SMS
       MMAX=MMAX-1                                                       SMS
-      IF (M.EQ.MMAX) GO TO 150                                          SMS
+      IF (M .EQ. MMAX) GO TO 150                                          SMS
       DO 46 MM=M+1,MMAX                                                 SMS
       JZ(MM)=JZ(MM+1)                                                   SMS
    46 WT(MM)=WT(MM+1)                                                   SMS
@@ -642,10 +642,10 @@ C        NOW THAT IN ASCENDING ORDER, COMBINE IDENTICAL Zs              SMS
       CALL FORM(FORMLA,MMAX,JZ,WT)
       GO TO 25
    55 continue
-ckkk      PRINT *,' How many components in mixture? Enter number: '
-ckkk      READ *,NCOMP
-ckkk      PRINT 10
-c//////
+!kkk      PRINT *,' How many components in mixture? Enter number: '
+!kkk      READ *,NCOMP
+!kkk      PRINT 10
+!//////
       call copenfw2(55,
      *   basepath(1:nbasepath), 1, icon)
       if(icon .ne. 1) then
@@ -653,55 +653,55 @@ c//////
          stop 2345
       endif
       call epReadMTbl(55, media)
-      NCOMP=media.noOfElem
+      NCOMP=media%noOfElem
       call epGetEffZA(media)
-      write(0,*) media.name, ' No. of constituent atoms=', NCOMP
-c/////////
+      write(0,*) media%name, ' No. of constituent atoms=', NCOMP
+!/////////
       DO 65 N=1,NCOMP
-ckkk      PRINT 60,N
-ckkk   60 FORMAT(' Enter chemical symbol or formula for component',
-ckkk     1 I3,': ')
-ckkk      READ 12, FRM(N)
-c//////
+!kkk      PRINT 60,N
+!kkk   60 FORMAT(' Enter chemical symbol or formula for component',
+!kkk     1 I3,': ')
+!kkk      READ 12, FRM(N)
+!//////
          FRM(N)=" "
-         call epZ2ChemSymb(int(media.elem(N).Z), symb)
+         call epZ2ChemSymb(int(media%elem(N)%Z), symb)
          FRM(N)=symb
-         write(0,*) symb, ' Z=', media.elem(N).Z, ' W=',media.w(N)
-c////////
-ckkk      PRINT 61,N
-ckkk   61 FORMAT(' Enter fraction by weight for component',I3,': ')
-ckk      READ *, FRAC(N)
-c///////
-         FRAC(N)=media.w(N)
-c///////
+         write(0,*) symb, ' Z=', media%elem(N)%Z, ' W=',media%w(N)
+!////////
+!kkk      PRINT 61,N
+!kkk   61 FORMAT(' Enter fraction by weight for component',I3,': ')
+!kk      READ *, FRAC(N)
+!///////
+         FRAC(N)=media%w(N)
+!///////
    65 CONTINUE
-ckkkk     PRINT 10
+!kkkk     PRINT 10
       SUMF=0.0
       DO 70 N=1,NCOMP
    70 SUMF=SUMF+FRAC(N)
-ckk      write(0,72)
-ckk   72 FORMAT('   Component    Fraction')
-ckk      write(0,73)
-ckk   73 FORMAT('               by Weight')
-ckkk      PRINT 10
-ckk      DO 75 N=1,NCOMP
-ckk         write(0, 74) N,FRAC(N),FRM(N)
-ckk   74 FORMAT(I12,F12.6,6X,A)
-ckk   75 CONTINUE
-ckkk      PRINT 10
-ckk       write(0, 80) SUMF
+!kk      write(0,72)
+!kk   72 FORMAT('   Component    Fraction')
+!kk      write(0,73)
+!kk   73 FORMAT('               by Weight')
+!kkk      PRINT 10
+!kk      DO 75 N=1,NCOMP
+!kk         write(0, 74) N,FRAC(N),FRM(N)
+!kk   74 FORMAT(I12,F12.6,6X,A)
+!kk   75 CONTINUE
+!kkk      PRINT 10
+!kk       write(0, 80) SUMF
    80 FORMAT(6X,'Sum = ',F12.6)
-ckkk      PRINT 10
-ckkk      PRINT *,' Options for accepting or rejecting composition data:'
-ckkk      PRINT *,'     1. Accept, but let program normalize fractions'
-ckkk      PRINT *,'        by weight so that their sum is unity'
-ckk      PRINT *,'     2. Reject, and enter different set of fractions'
-ckk      PRINT *,' Enter choice: '
-ckkk      READ *,MSUMGO
-ckkk      PRINT 10
-c/////
+!kkk      PRINT 10
+!kkk      PRINT *,' Options for accepting or rejecting composition data:'
+!kkk      PRINT *,'     1. Accept, but let program normalize fractions'
+!kkk      PRINT *,'        by weight so that their sum is unity'
+!kk      PRINT *,'     2. Reject, and enter different set of fractions'
+!kk      PRINT *,' Enter choice: '
+!kkk      READ *,MSUMGO
+!kkk      PRINT 10
+!/////
       MSUMGO=1
-c////////
+!////////
       GO TO (85,55), MSUMGO
    85 DO 90 N=1,NCOMP
    90 FRAC(N)=FRAC(N)/SUMF
@@ -726,16 +726,16 @@ c////////
   140 CONTINUE
       MMAX=LL
   150 continue 
-ckkk      PRINT *,' Options for energy list for output data:'
-ckkk      PRINT *,'     1. Standard energy grid only'
-ckkk      PRINT *,'     2. Standard grid plus additional energies'
-ckkk      PRINT *,'     3. Additional energies only'
-ckkk      PRINT *,' Enter choice: '
-ckk      READ *,NELL
-ckk     PRINT 10
-c//////
+!kkk      PRINT *,' Options for energy list for output data:'
+!kkk      PRINT *,'     1. Standard energy grid only'
+!kkk      PRINT *,'     2. Standard grid plus additional energies'
+!kkk      PRINT *,'     3. Additional energies only'
+!kkk      PRINT *,' Enter choice: '
+!kk      READ *,NELL
+!kk     PRINT 10
+!//////
       NELL=1
-c///////
+!///////
       GO TO (240,190,190), NELL
   190 PRINT *,' Modes of entering additional energies:'
       PRINT *,'     1. Entry from keyboard'
@@ -756,7 +756,7 @@ c///////
       PRINT 10
       PRINT *,' Save additional energies in file? (Y/N): '              SMS
       READ *,RESP                                                       SMS
-      IF (RESP.NE.'Y'.AND.RESP.NE.'y') GO TO 220                        SMS
+      IF (RESP .NE. 'Y' .AND. RESP .NE. 'y') GO TO 220                        SMS
       PRINT *,' Specify file name to save this energy list.'            SMS
       PRINT *,' (Specification can include drive and path): '           SMS
       READ 12, ENGIN                                                    SMS
@@ -773,7 +773,7 @@ c///////
       READ 12, ENGIN
       PRINT 10
       OPEN (UNIT=7,FILE=ENGIN)
-c/////////////K.K
+!/////////////K.K
       JING=0
       do while(.true.)
          READ (7,*, end=9999 ) EADD(JING+1)
@@ -784,25 +784,25 @@ c/////////////K.K
   220 DO 230 J=1,JING
   230 EADD(J)=EADD(J)*1.0E+06
       CALL SORT (JING,EADD)                                             SMS
-cccccccccccccccccccccccccccccc
+!ccccccccccccccccccccccccccccc
   240 CONTINUE                                                          SMS
-C 240 PRINT *,' Options for entry of Database files:'
-C     PRINT *,'    1. Read files from floppy-disk drive A'
-C     PRINT *,'    2. Read files from floppy-disk drive B'
-C     PRINT *,'    3. Read files from CURRENT directory on hard disk'
-C     PRINT *,' Enter choice: '
-C     READ *, INDAT
-C     GO TO (241,242,243),INDAT
-C 241 SOURCE='A:MDATX3.'
-C     RETURN
-C 242 SOURCE='B:MDATX3.'
-C     RETURN
+! 240 PRINT *,' Options for entry of Database files:'
+!     PRINT *,'    1. Read files from floppy-disk drive A'
+!     PRINT *,'    2. Read files from floppy-disk drive B'
+!     PRINT *,'    3. Read files from CURRENT directory on hard disk'
+!     PRINT *,' Enter choice: '
+!     READ *, INDAT
+!     GO TO (241,242,243),INDAT
+! 241 SOURCE='A:MDATX3.'
+!     RETURN
+! 242 SOURCE='B:MDATX3.'
+!     RETURN
   243 SOURCE='MDATX3.'
       RETURN
       END
  
       SUBROUTINE FORM (W,MMAX,JZ,WT)
-C     24 Mar 87. Reads element symbols or chemical formulas.
+!     24 Mar 87. Reads element symbols or chemical formulas.
       CHARACTER*72,W
       DIMENSION MASH1(26),MASH2(418),IC(72),K(72),JZ(100),NZ(100),
      1 MS(100),ATWTS(100),WT(100)
@@ -919,13 +919,13 @@ C     24 Mar 87. Reads element symbols or chemical formulas.
       END
 
       SUBROUTINE SORT (NMAX,E)                                          SMS
-C     16 Jun 99. Sorts into monotonically increasing order.             SMS
+!     16 Jun 99. Sorts into monotonically increasing order.             SMS
       DIMENSION E(1)                                                    SMS
       DATA  EBIG/1.0E20/                                                SMS
       DO 20 M=1,NMAX-1                                                  SMS
       EMIN=EBIG                                                         SMS
       DO 10 N=M,NMAX                                                    SMS
-      IF (E(N).GT.EMIN) GO TO 10                                        SMS
+      IF (E(N) .GT. EMIN) GO TO 10                                        SMS
       EMIN=E(N)                                                         SMS
       NS=N                                                              SMS
    10 CONTINUE                                                          SMS
@@ -936,7 +936,7 @@ C     16 Jun 99. Sorts into monotonically increasing order.             SMS
       END                                                               SMS
 
       SUBROUTINE MERGE(E1,K1,L1,MMAX,E2,K2,L2,NMAX)
-C     24 Mar 87. Merges energy lists.
+!     24 Mar 87. Merges energy lists.
       DIMENSION E1(1),K1(1),L1(1),E2(1),K2(1),L2(1)
       DATA MLIM/200/
       DO 50 N=1,NMAX
@@ -962,7 +962,7 @@ C     24 Mar 87. Merges energy lists.
       END
 
       SUBROUTINE REV(NMAX,X)
-C     24 Mar 87. Reverses the order of lists.
+!     24 Mar 87. Reverses the order of lists.
       DIMENSION X(1)
       NH=NMAX/2 
       DO 10 N=1,NH
@@ -974,8 +974,8 @@ C     24 Mar 87. Reverses the order of lists.
       END 
        
       SUBROUTINE SCOF(X,F,NMAX,A,B,C,D) 
-C     22 Feb 83. Fits F as a function of X, and calculates 
-C                cubic spline coefficients A,B,C and D.
+!     22 Feb 83. Fits F as a function of X, and calculates 
+!                cubic spline coefficients A,B,C and D.
       DIMENSION X(1),F(1),A(1),B(1),C(1),D(1) 
       M1=2
       M2=NMAX-1 
@@ -1009,10 +1009,10 @@ C                cubic spline coefficients A,B,C and D.
       END 
        
       SUBROUTINE BSPOL(S,X,A,B,C,D,N,G)
-C     22 Feb 83. Evaluates cubic spline as function of S, to obtain
-C                fitted result G.
+!     22 Feb 83. Evaluates cubic spline as function of S, to obtain
+!                fitted result G.
       DIMENSION X(1),A(1),B(1),C(1),D(1)
-      IF (X(1).GT.X(N)) GO TO 10
+      IF (X(1) .GT. X(N)) GO TO 10
       IDIR=0
       MLB=0 
       MUB=N 
@@ -1020,14 +1020,14 @@ C                fitted result G.
    10 IDIR=1
       MLB=N 
       MUB=0 
-   20 IF (S.GE.X(MUB+IDIR)) GO TO 60
-      IF (S.LE.X(MLB+1-IDIR)) GO TO 70
+   20 IF (S .GE. X(MUB+IDIR)) GO TO 60
+      IF (S .LE. X(MLB+1-IDIR)) GO TO 70
       ML=MLB
       MU=MUB
       GO TO 40
-   30 IF (IABS(MU-ML).LE.1) GO TO 80
+   30 IF (IABS(MU-ML) .LE. 1) GO TO 80
    40 MAV=(ML+MU)/2 
-      IF (S.LT.X(MAV)) GO TO 50 
+      IF (S .LT. X(MAV)) GO TO 50 
       ML=MAV
       GO TO 30
    50 MU=MAV
@@ -1043,9 +1043,9 @@ C                fitted result G.
       END 
        
       SUBROUTINE BLIN(S,X,Y,N,T)
-C     12 Apr 87. Linear interpolation routine
+!     12 Apr 87. Linear interpolation routine
       DIMENSION X(1000),Y(1000)
-      IF (X(1).GT.X(N)) GO TO 10
+      IF (X(1) .GT. X(N)) GO TO 10
       IDIR=0
       MLB=0 
       MUB=N 
@@ -1053,14 +1053,14 @@ C     12 Apr 87. Linear interpolation routine
    10 IDIR=1
       MLB=N 
       MUB=0 
-   20 IF (S.GE.X(MUB+IDIR)) GO TO 60
-      IF (S.LE.X(MLB+1-IDIR)) GO TO 70
+   20 IF (S .GE. X(MUB+IDIR)) GO TO 60
+      IF (S .LE. X(MLB+1-IDIR)) GO TO 70
       ML=MLB
       MU=MUB
       GO TO 40
-   30 IF (IABS(MU-ML).LE.1) GO TO 80
+   30 IF (IABS(MU-ML) .LE. 1) GO TO 80
    40 MAV=(ML+MU)/2 
-      IF (S.LT.X(MAV)) GO TO 50 
+      IF (S .LT. X(MAV)) GO TO 50 
       ML=MAV
       GO TO 30
    50 MU=MAV
